==> jc-1.4.0.tar.gz: gnu/classpath/RawData.h <==
// public abstract class gnu.classpath.RawData

// class file dependencies
// @dep_class 62c7aaff42351a78 gnu_classpath_RawData
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_RawData_H_
#define _JC_gnu_classpath_RawData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_classpath_RawData$sub_refs	_jc_gnu_classpath_RawData$sub_refs;
typedef struct _jc_gnu_classpath_RawData$sub_nonrefs	_jc_gnu_classpath_RawData$sub_nonrefs;
typedef struct _jc_gnu_classpath_RawData$refs	_jc_gnu_classpath_RawData$refs;
typedef struct _jc_gnu_classpath_RawData$nonrefs	_jc_gnu_classpath_RawData$nonrefs;
typedef struct _jc_gnu_classpath_RawData$object	_jc_gnu_classpath_RawData$object;

typedef const struct _jc_gnu_classpath_RawData$vmethods	_jc_gnu_classpath_RawData$vmethods;
typedef const struct _jc_gnu_classpath_RawData$vtable	_jc_gnu_classpath_RawData$vtable;
typedef const struct _jc_gnu_classpath_RawData$vtype	_jc_gnu_classpath_RawData$vtype;

// Constructors
extern void _jc_gnu_classpath_RawData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_RawData$object *);

// Virtual methods structure
struct _jc_gnu_classpath_RawData$vmethods {
};

// Vtable
struct _jc_gnu_classpath_RawData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_RawData$vmethods	gnu_classpath_RawData;
};

// Vtype
struct _jc_gnu_classpath_RawData$vtype {
	_jc_type			type;
	_jc_gnu_classpath_RawData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_RawData$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_RawData$refs {
    _jc_gnu_classpath_RawData$sub_refs	gnu_classpath_RawData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_RawData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_RawData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_RawData$sub_nonrefs	gnu_classpath_RawData;
};

// Object instance structure
struct _jc_gnu_classpath_RawData$object {
	_jc_gnu_classpath_RawData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_RawData$vtype	*vtype;
	_jc_gnu_classpath_RawData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_RawData$vtype _jc_gnu_classpath_RawData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_RawData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_RawData$class_object;

#endif	/* _JC_gnu_classpath_RawData_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/RawData.h <==
// public abstract class gnu.classpath.RawData

// class file dependencies
// @dep_class 62c7aaff42351a78 gnu_classpath_RawData
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_RawData_H_
#define _JC_gnu_classpath_RawData_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_classpath_RawData$sub_refs	_jc_gnu_classpath_RawData$sub_refs;
typedef struct _jc_gnu_classpath_RawData$sub_nonrefs	_jc_gnu_classpath_RawData$sub_nonrefs;
typedef struct _jc_gnu_classpath_RawData$refs	_jc_gnu_classpath_RawData$refs;
typedef struct _jc_gnu_classpath_RawData$nonrefs	_jc_gnu_classpath_RawData$nonrefs;
typedef struct _jc_gnu_classpath_RawData$object	_jc_gnu_classpath_RawData$object;

typedef const struct _jc_gnu_classpath_RawData$vmethods	_jc_gnu_classpath_RawData$vmethods;
typedef const struct _jc_gnu_classpath_RawData$vtable	_jc_gnu_classpath_RawData$vtable;
typedef const struct _jc_gnu_classpath_RawData$vtype	_jc_gnu_classpath_RawData$vtype;

// Constructors
extern void _jc_gnu_classpath_RawData$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_RawData$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_RawData$vmethods {
};

// Vtable
struct _jc_gnu_classpath_RawData$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_RawData$vmethods	gnu_classpath_RawData;
};

// Vtype
struct _jc_gnu_classpath_RawData$vtype {
	_jc_type			type;
	_jc_gnu_classpath_RawData$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_RawData$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_RawData$refs {
    _jc_gnu_classpath_RawData$sub_refs	gnu_classpath_RawData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_RawData$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_RawData$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_RawData$sub_nonrefs	gnu_classpath_RawData;
};

// Object instance structure
struct _jc_gnu_classpath_RawData$object {
	_jc_gnu_classpath_RawData$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_RawData$vtype	*vtype;
	_jc_gnu_classpath_RawData$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_RawData$vtype _jc_gnu_classpath_RawData$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_RawData, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_RawData$class_object;

#endif	/* _JC_gnu_classpath_RawData_H_ */
